#
# spec file for package gnome-desktop
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define IS_DEFAULT_GNOME_DESKTOP 1

Name:           gnome-desktop
Version:        3.10.1
Release:        0
Summary:        The GNOME Desktop API Library
License:        LGPL-2.1+
Group:          System/GUI/GNOME
Url:            http://www.gnome.org
Source:         http://download.gnome.org/sources/gnome-desktop/3.10/%{name}-%{version}.tar.xz
Source99:       baselibs.conf
BuildRequires:  fdupes
BuildRequires:  gobject-introspection-devel
BuildRequires:  intltool
BuildRequires:  translation-update-upstream
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.35.0
BuildRequires:  pkgconfig(gsettings-desktop-schemas) >= 3.5.91
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.3.6
BuildRequires:  pkgconfig(iso-codes)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext) >= 1.1
BuildRequires:  pkgconfig(xkbfile)
BuildRequires:  pkgconfig(xkeyboard-config)
BuildRequires:  pkgconfig(xrandr) >= 1.3
%if 0%{?BUILD_FROM_VCS}
BuildRequires:  gnome-common
BuildRequires:  gtk-doc
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package contains the desktop-wide files.

%if %IS_DEFAULT_GNOME_DESKTOP || 0%{?BUILD_FROM_VCS}

%package -n gnome-version
Summary:        GNOME version
Group:          System/GUI/GNOME
%if %IS_DEFAULT_GNOME_DESKTOP
Obsoletes:      gnome-about < %{version}
%endif

%description -n gnome-version
This package contains information on the version of GNOME that is installed.
%endif

%package -n libgnome-desktop-3_0-common
Summary:        The GNOME Desktop API Library -- Common data files
Group:          System/Libraries

%description -n libgnome-desktop-3_0-common
The libgnome-desktop library provides API shared by several applications
on the desktop, but that cannot live in the platform for various
reasons.

This package contains data files used by libgnome-dekstop.

%package -n libgnome-desktop-3-8
Summary:        The GNOME Desktop API Library
Group:          System/GUI/GNOME
Requires:       gsettings-desktop-schemas
# Data files for libgnome-desktop, split in an own package for SLPP compliancy
Requires:       libgnome-desktop-3_0-common >= %{version}
Recommends:     %{name}-lang
Provides:       %{name} = %{version}
%if %IS_DEFAULT_GNOME_DESKTOP
Obsoletes:      %{name} < %{version}
%endif

%description -n libgnome-desktop-3-8
The libgnome-desktop library provides API shared by several applications
on the desktop, but that cannot live in the platform for various
reasons.

%package -n typelib-1_0-GnomeDesktop-3_0
Summary:        The GNOME Desktop API Library -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-GnomeDesktop-3_0
The libgnome-desktop library provides API shared by several applications
on the desktop, but that cannot live in the platform for various
reasons.

This package provides the GObject Introspection bindings for
libgnome-desktop.

%package -n libgnome-desktop-3-devel
Summary:        The GNOME Desktop API Library -- Development Files
Group:          Development/Libraries/GNOME
Requires:       libgnome-desktop-3-8 = %{version}
Requires:       typelib-1_0-GnomeDesktop-3_0 = %{version}
# Needed as /usr/include/gnome-desktop-3.0/libgnome-desktop/gnome-xkb-info.h includes X11/extensions/XKBrules.h
Requires:       libxkbfile-devel
%if %IS_DEFAULT_GNOME_DESKTOP
Provides:       %{name}-devel = %{version}
Obsoletes:      %{name}-devel < %{version}
Provides:       %{name}-doc = %{version}
Obsoletes:      %{name}-doc < %{version}
%endif

%description -n libgnome-desktop-3-devel
The libgnome-desktop library provides API shared by several applications
on the desktop, but that cannot live in the platform for various
reasons.

%lang_package
%prep
%setup -q
translation-update-upstream

%if 0%{?BUILD_FROM_VCS}
[ -x ./autogen.sh] && NOCONFIGURE=1 ./autogen.sh
%endif

%build
%configure --with-pic\
	--disable-static\
%if 0%{?BUILD_FROM_VCS}
        --enable-gtk-doc \
%endif
        --disable-scrollkeeper \
        --with-gnome-distributor="SUSE" \
        --disable-date-in-gnome-version
make %{?_smp_mflags} V=1

%install
%makeinstall
%find_lang %{name}-3.0 %{?no_lang_C}
%find_lang fdl %{?no_lang_C} %{name}-3.0.lang
%find_lang gpl %{?no_lang_C} %{name}-3.0.lang
%find_lang lgpl %{?no_lang_C} %{name}-3.0.lang
%if ! (%IS_DEFAULT_GNOME_DESKTOP || 0%{?BUILD_FROM_VCS})
rm %{buildroot}%{_datadir}/gnome/gnome-version.xml
%endif
%{__rm} -vf %{buildroot}%{_libdir}/*.la
%fdupes %{buildroot}

%clean
rm -rf %{buildroot}

%post -n libgnome-desktop-3-8 -p /sbin/ldconfig

%postun -n libgnome-desktop-3-8 -p /sbin/ldconfig

%files -n libgnome-desktop-3-8
%defattr(-, root, root)
%doc AUTHORS COPYING.LIB NEWS README
%{_libdir}/libgnome-desktop-3.so.*

%files -n libgnome-desktop-3_0-common
%defattr(-,root,root)
%doc %{_datadir}/help/C/fdl/
%doc %{_datadir}/help/C/gpl/
%doc %{_datadir}/help/C/lgpl/
%{_datadir}/libgnome-desktop-3.0/
%{_libexecdir}/gnome-rr-debug

%files -n typelib-1_0-GnomeDesktop-3_0
%defattr(-,root,root)
%{_libdir}/girepository-1.0/GnomeDesktop-3.0.typelib

%files -n libgnome-desktop-3-devel
%defattr (-, root, root)
%{_includedir}/gnome-desktop-3.0/
%{_libdir}/libgnome-desktop-3.so
%{_libdir}/pkgconfig/gnome-desktop-3.0.pc
%{_datadir}/gir-1.0/*.gir
%doc %{_datadir}/gtk-doc/html/gnome-desktop3/

%files lang -f %{name}-3.0.lang

%if %IS_DEFAULT_GNOME_DESKTOP || 0%{?BUILD_FROM_VCS}

%files -n gnome-version
%defattr (-, root, root)
%dir %{_datadir}/gnome
%{_datadir}/gnome/gnome-version.xml
%endif

%changelog
